@@ -4,12 +4,14 @@ import os
 from PIL import Image
 from progressbar import progressbar
 
-def download_from_google_images(keywords : str, limit : int, directory : str):
+def download_from_google_images(keywords : str, limit : int, class_name : str):
 
     if(limit>1000):
         print('Too much images')
         return
 
+    os.makedirs("dataset", exist_ok=True)
+
     url = 'https://us-central1-kasar-lab.cloudfunctions.net/scrapeImages'
     args = {'keywords': keywords, 'limit': limit}
 
@@ -18,15 +20,15 @@ def download_from_google_images(keywords : str, limit : int, directory : str):
 
     json_res = json.loads(res.text)
     print(len(json_res), "urls fetched")
-    os.makedirs(directory, exist_ok=True)
+    os.makedirs(class_name, exist_ok=True)
 
     print("Downloading images...")
     for el in progressbar(json_res):
-        download_image(el["url"], directory)
+        download_image(el["url"], class_name)
 
-def download_image(image_url, directory):
+def download_image(image_url, class_name):
     filename = image_url.split("/")[-1].split("?")[0]
-    path = f'{directory}/{filename}'
+    path = f'dataset/{class_name}/{filename}'
 
     if os.path.exists(path):
         return
